==> net.bluemind.p2.platform-4.9.3879.zip: store/types/actions.js <==
// partsData
export const FETCH_PART_DATA = "FETCH_PART_DATA";

// mailboxes
export const FETCH_MAILBOXES = "FETCH_MAILBOXES";

// folders
export const CREATE_FOLDER = "CREATE_FOLDER";
export const CREATE_FOLDER_HIERARCHY = "CREATE_FOLDER_HIERARCHY";
export const EMPTY_FOLDER = "EMPTY_FOLDER";
export const EMPTY_TRASH = "EMPTY_TRASH";
export const FETCH_FOLDERS = "FETCH_FOLDERS";
export const MARK_FOLDER_AS_READ = "MARK_FOLDER_AS_READ";
export const MOVE_FOLDER = "MOVE_FOLDER";
export const REMOVE_FOLDER = "REMOVE_FOLDER";
export const RENAME_FOLDER = "RENAME_FOLDER";
export const UNREAD_FOLDER_COUNT = "$_VueBus_mail-webapp_unread_folder_count";
export const PUSHED_FOLDER_CHANGES = "$_VueBus_mail-webapp_pushed_folder_changes";

// messages
export const ADD_ATTACHMENT = "ADD_ATTACHMENT";
export const ADD_FLAG = "ADD_FLAG";
export const DEBOUNCED_SAVE_MESSAGE = "DEBOUNCED_SAVE_MESSAGE";
export const DELETE_FLAG = "DELETE_FLAG";
export const FETCH_MESSAGE_IF_NOT_LOADED = "FETCH_MESSAGE_IF_NOT_LOADED";
export const FETCH_MESSAGE_METADATA = "FETCH_MESSAGE_METADATA";
export const MARK_MESSAGE_AS_FLAGGED = "MARK_MESSAGE_AS_FLAGGED";
export const MARK_MESSAGE_AS_READ = "MARK_MESSAGE_AS_READ";
export const MARK_MESSAGE_AS_UNFLAGGED = "MARK_MESSAGE_AS_UNFLAGGED";
export const MARK_MESSAGE_AS_UNREAD = "MARK_MESSAGE_AS_UNREAD";
export const MARK_MESSAGES_AS_FLAGGED = "MARK_MESSAGES_AS_FLAGGED";
export const MARK_MESSAGES_AS_READ = "MARK_MESSAGES_AS_READ";
export const MARK_MESSAGES_AS_UNFLAGGED = "MARK_MESSAGES_AS_UNFLAGGED";
export const MARK_MESSAGES_AS_UNREAD = "MARK_MESSAGES_AS_UNREAD";
export const MOVE_MESSAGES = "MOVE_MESSAGES";
export const REMOVE_ATTACHMENT = "REMOVE_ATTACHMENT";
export const REMOVE_MESSAGES = "REMOVE_MESSAGES";
export const REQUEST_DSN = "REQUEST_DSN";
export const TOGGLE_DSN_REQUEST = "TOGGLE_DSN_REQUEST";
export const SAVE_AS_DRAFT = "SAVE_AS_DRAFT";
export const SAVE_AS_TEMPLATE = "SAVE_AS_TEMPLATE";
export const SAVE_MESSAGE = "SAVE_MESSAGE";
export const SEND_MESSAGE = "SEND_MESSAGE";

// conversationList
export const FETCH_CONVERSATION_LIST_KEYS = "FETCH_CONVERSATION_LIST_KEYS";
export const CONVERSATION_LIST_NEXT_PAGE = "CONVERSATION_LIST_NEXT_PAGE";
export const REFRESH_CONVERSATION_LIST_KEYS = "REFRESH_CONVERSATION_LIST_KEYS";

// messageCompose
export const CHECK_CORPORATE_SIGNATURE = "CHECK_CORPORATE_SIGNATURE";
export const FETCH_TEMPLATES_KEYS = "FETCH_TEMPLATES_KEYS";
export const LOAD_MAX_MESSAGE_SIZE = "LOAD_MAX_MESSAGE_SIZE";

// consultPanel
export const FETCH_EVENT = "FETCH_EVENT";
export const SET_EVENT_STATUS = "SET_EVENT_STATUS";
export const ACCEPT_COUNTER_EVENT = "ACCEPT_COUNTER_EVENT";
export const DECLINE_COUNTER_EVENT = "DECLINE_COUNTER_EVENT";

// conversations
export const FETCH_CONVERSATION_IF_NOT_LOADED = "FETCH_CONVERSATION_IF_NOT_LOADED";
export const FETCH_CONVERSATIONS = "FETCH_CONVERSATIONS";
export const MARK_CONVERSATIONS_AS_FLAGGED = "MARK_CONVERSATIONS_AS_FLAGGED";
export const MARK_CONVERSATIONS_AS_READ = "MARK_CONVERSATIONS_AS_READ";
export const MARK_CONVERSATIONS_AS_UNFLAGGED = "MARK_CONVERSATIONS_AS_UNFLAGGED";
export const MARK_CONVERSATIONS_AS_UNREAD = "MARK_CONVERSATIONS_AS_UNREAD";
export const MOVE_CONVERSATION_MESSAGES = "MOVE_CONVERSATION_MESSAGES";
export const MOVE_CONVERSATIONS = "MOVE_CONVERSATIONS";
export const REMOVE_CONVERSATION_MESSAGES = "REMOVE_CONVERSATION_MESSAGES";
export const REMOVE_CONVERSATIONS = "REMOVE_CONVERSATIONS";

// folderList
export const RESET_FILTER = "RESET_FILTER";
export const SHOW_MORE_FOR_GROUP_MAILBOXES = "SHOW_MORE_FOR_GROUP_MAILBOXES";
export const SHOW_MORE_FOR_MAILSHARES = "SHOW_MORE_FOR_MAILSHARES";
export const SHOW_MORE_FOR_USERS = "SHOW_MORE_FOR_USERS";

// address weights
export const ADD_ADDRESS_WEIGHT = "ADD_ADDRESS_WEIGHT";
export const DELETE_ADDRESS_WEIGHTS = "DELETE_ADDRESS_WEIGHTS";
export const SET_ADDRESS_WEIGHT = "SET_ADDRESS_WEIGHT";

// search
export const RESET_CURRENT_SEARCH = "RESET_CURRENT_SEARCH";

==> net.bluemind.p2.platform-5.4.2760.zip: store/types/actions.js <==
// partsData
export const FETCH_PART_DATA = "FETCH_PART_DATA";

// mailboxes
export const FETCH_MAILBOXES = "FETCH_MAILBOXES";

// folders
export const CREATE_FOLDER = "CREATE_FOLDER";
export const CREATE_FOLDER_HIERARCHY = "CREATE_FOLDER_HIERARCHY";
export const EMPTY_FOLDER = "EMPTY_FOLDER";
export const EMPTY_TRASH = "EMPTY_TRASH";
export const FETCH_FOLDERS = "FETCH_FOLDERS";
export const MARK_FOLDER_AS_READ = "MARK_FOLDER_AS_READ";
export const MOVE_FOLDER = "MOVE_FOLDER";
export const REMOVE_FOLDER = "REMOVE_FOLDER";
export const RENAME_FOLDER = "RENAME_FOLDER";
export const UNREAD_FOLDER_COUNT = "$_VueBus_mail-webapp_unread_folder_count";
export const PUSHED_FOLDER_CHANGES = "$_VueBus_mail-webapp_pushed_folder_changes";
export const INIT_UNREAD_COUNTS = "INIT_UNREAD_COUNTS";

// messages
export const ADD_ATTACHMENT = "ADD_ATTACHMENT";
export const ADD_FLAG = "ADD_FLAG";
export const ADD_LOCAL_ATTACHMENT = "ADD_LOCAL_ATTACHMENT";
export const DEBOUNCED_SAVE_MESSAGE = "DEBOUNCED_SAVE_MESSAGE";
export const DEBOUNCED_SET_MESSAGE_CONTENT = "DEBOUNCED_SET_MESSAGE_CONTENT";
export const DELETE_FLAG = "DELETE_FLAG";
export const FETCH_MESSAGE_IF_NOT_LOADED = "FETCH_MESSAGE_IF_NOT_LOADED";
export const FETCH_MESSAGE_METADATA = "FETCH_MESSAGE_METADATA";
export const FLUSH_COMPOSER_ACTIONS = "FLUSH_COMPOSER_ACTIONS";
export const IMPORT_EML = "IMPORT_EML";
export const MARK_MESSAGE_AS_FLAGGED = "MARK_MESSAGE_AS_FLAGGED";
export const MARK_MESSAGE_AS_READ = "MARK_MESSAGE_AS_READ";
export const MARK_MESSAGE_AS_UNFLAGGED = "MARK_MESSAGE_AS_UNFLAGGED";
export const MARK_MESSAGE_AS_UNREAD = "MARK_MESSAGE_AS_UNREAD";
export const MARK_MESSAGES_AS_FLAGGED = "MARK_MESSAGES_AS_FLAGGED";
export const MARK_MESSAGES_AS_READ = "MARK_MESSAGES_AS_READ";
export const MARK_MESSAGES_AS_UNFLAGGED = "MARK_MESSAGES_AS_UNFLAGGED";
export const MARK_MESSAGES_AS_UNREAD = "MARK_MESSAGES_AS_UNREAD";
export const MOVE_MESSAGES = "MOVE_MESSAGES";
export const REMOVE_ATTACHMENT = "REMOVE_ATTACHMENT";
export const REMOVE_MESSAGES = "REMOVE_MESSAGES";
export const REQUEST_DSN = "REQUEST_DSN";
export const SAVE_AS_DRAFT = "SAVE_AS_DRAFT";
export const SAVE_AS_TEMPLATE = "SAVE_AS_TEMPLATE";
export const SAVE_MESSAGE = "SAVE_MESSAGE";
export const SEND_MESSAGE = "SEND_MESSAGE";
export const SEND_MDN_TEMPLATE = "SEND_MDN_TEMPLATE";
export const SET_SUSPECTED_PHISHING = "SET_SUSPECTED_PHISHING";
export const SCHEDULE_SEND_MESSAGE = "SCHEDULE_SEND_MESSAGE";
export const TOGGLE_DSN_REQUEST = "TOGGLE_DSN_REQUEST";
export const UPDATE_MESSAGE_STRUCTURE = "UPDATE_MESSAGE_STRUCTURE";

// conversationList
export const FETCH_CONVERSATION_LIST_KEYS = "FETCH_CONVERSATION_LIST_KEYS";
export const CONVERSATION_LIST_NEXT_PAGE = "CONVERSATION_LIST_NEXT_PAGE";
export const REFRESH_CONVERSATION_LIST_KEYS = "REFRESH_CONVERSATION_LIST_KEYS";

// messageCompose
export const FETCH_TEMPLATES_KEYS = "FETCH_TEMPLATES_KEYS";
export const LOAD_MAX_MESSAGE_SIZE = "LOAD_MAX_MESSAGE_SIZE";
export const SET_DRAFT_CONTENT = "SET_DRAFT_CONTENT";
export const SET_MESSAGE_CONTENT = "SET_MESSAGE_CONTENT";
export const TOGGLE_SIGNATURE = "TOGGLE_SIGNATURE";
export const UPDATE_SIGNATURE = "UPDATE_SIGNATURE";

// consultPanel
export const FETCH_EVENT = "FETCH_EVENT";
export const REMOVE_EVENT = "REMOVE_EVENT";
export const SET_EVENT_STATUS = "SET_EVENT_STATUS";
export const ACCEPT_COUNTER_EVENT = "ACCEPT_COUNTER_EVENT";
export const DECLINE_COUNTER_EVENT = "DECLINE_COUNTER_EVENT";
export const REJECT_ATTENDEES = "REJECT_ATTENDEES";

// conversations
export const FETCH_CONVERSATION_IF_NOT_LOADED = "FETCH_CONVERSATION_IF_NOT_LOADED";
export const FETCH_CONVERSATIONS = "FETCH_CONVERSATIONS";
export const MARK_CONVERSATIONS_AS_FLAGGED = "MARK_CONVERSATIONS_AS_FLAGGED";
export const MARK_CONVERSATIONS_AS_READ = "MARK_CONVERSATIONS_AS_READ";
export const MARK_CONVERSATIONS_AS_UNFLAGGED = "MARK_CONVERSATIONS_AS_UNFLAGGED";
export const MARK_CONVERSATIONS_AS_UNREAD = "MARK_CONVERSATIONS_AS_UNREAD";
export const MOVE_CONVERSATION_MESSAGES = "MOVE_CONVERSATION_MESSAGES";
export const MOVE_CONVERSATIONS = "MOVE_CONVERSATIONS";
export const REMOVE_CONVERSATION_MESSAGES = "REMOVE_CONVERSATION_MESSAGES";
export const REMOVE_CONVERSATIONS = "REMOVE_CONVERSATIONS";
export const UNEXPUNGE = "UNEXPUNGE";

// folderList
export const RESET_FILTER = "RESET_FILTER";
export const SHOW_MORE_FOR_GROUP_MAILBOXES = "SHOW_MORE_FOR_GROUP_MAILBOXES";
export const SHOW_MORE_FOR_MAILSHARES = "SHOW_MORE_FOR_MAILSHARES";
export const SHOW_MORE_FOR_USERS = "SHOW_MORE_FOR_USERS";
export const TOGGLE_FOLDER_TREE = "TOGGLE_FOLDER_TREE";

// search
export const RESET_CURRENT_SEARCH = "RESET_CURRENT_SEARCH";

//preview
export const SHOW_PREVIEW = "SHOW_PREVIEW";
